@@ -10,30 +10,43 @@
 #' - 'base' for \url{https://lifemap.univ-lyon1.fr/}
 #' - 'virus' for \url{https://virusmap.univ-lyon1.fr/}
 #'
-#' @return An HTML widget object  with graphics layers.
+#' @return An HTML widget object with graphics layers.
 #' @export
 #' @importFrom leaflet leaflet addTiles providerTileOptions
 #' @importFrom RCurl url.exists
 #'
 #' @examples
 #' display_map()
-display_map <- function(df = NULL,basemap = c("fr","ncbi", "base","virus")) {
+display_map <- function(df = NULL, basemap = c("fr", "ncbi", "base", "virus")) {
   basemap <- match.arg(basemap)
   if (basemap == "fr"){
-    display="http://lifemap-fr.univ-lyon1.fr/osm_tiles/{z}/{x}/{y}.png"
+    display <- "http://lifemap-fr.univ-lyon1.fr/osm_tiles/{z}/{x}/{y}.png"
   } else if (basemap == "ncbi"){
-    display="http://lifemap-ncbi.univ-lyon1.fr/osm_tiles/{z}/{x}/{y}.png"
+    display <- "http://lifemap-ncbi.univ-lyon1.fr/osm_tiles/{z}/{x}/{y}.png"
   } else if (basemap == "base"){
-    display="http://lifemap.univ-lyon1.fr/osm_tiles/{z}/{x}/{y}.png"
+    display <- "http://lifemap.univ-lyon1.fr/osm_tiles/{z}/{x}/{y}.png"
   } else if (basemap == "virus"){
-    display="https://virusmap.univ-lyon1.fr/osm_tiles/{z}/{x}/{y}.png"
+    display <- "https://virusmap.univ-lyon1.fr/osm_tiles/{z}/{x}/{y}.png"
   }
-  url2check<-strsplit(display, "osm_tiles")[[1]][1]
-  if (!url.exists(url2check)) {
-    message("The Lifemap server or some remote lifemap files cannot be reached. Please try again later.")
-  } else {
-    m <- leaflet::leaflet(df) |>
+  url2check <- strsplit(display, "osm_tiles")[[1]][1]
+  
+  m <- tryCatch({
+    leaflet::leaflet(df) |>
       leaflet::addTiles(display, options = leaflet::providerTileOptions(minZoom = 5, maxZoom = 50))
+  },
+  warning = function(w) {
+    message("The Lifemap server or some remote lifemap files cannot be reached. Please try again later.")
+    return(NA)
+  },
+  error = function(e) {
+    message("The Lifemap server or some remote lifemap files cannot be reached. Please try again later.")
+    return(NA)
+  }
+  )
+  
+  if (!all(is.na(m))) {
     return(m)
+  } else {
+    return(NA)
   }
 }
